timeseries.SpaceCurve.arclength_param — GDA Toolbox v1.0 Manual

# timeseries.SpaceCurve.arclength_param

`SpaceCurve.` `arclength_param`()

  Change time parametrization to the universal speed=1 arclength parametrization.

  Examples

      >>> tn = np.arange(0, 5e9, 1e9)
      >>> s = SpaceCurve(tn=tn, px=(tn/1e9)**2)
      >>> s.data
                  time  pos_x  pos_y  pos_z  quality
      0            0.0    0.0    0.0    0.0       -1
      1000000000   1.0    1.0    0.0    0.0       -1
      2000000000   2.0    4.0    0.0    0.0       -1
      3000000000   3.0    9.0    0.0    0.0       -1
      4000000000   4.0   16.0    0.0    0.0       -1
      >>> a = s.arclength_param()
      >>> a.data
                   time  pos_x  pos_y  pos_z  quality
      0             0.0    0.0    0.0    0.0       -1
      1000000000    1.0    1.0    0.0    0.0       -1
      4000000000    4.0    4.0    0.0    0.0       -1
      9000000000    9.0    9.0    0.0    0.0       -1
      16000000000  16.0   16.0    0.0    0.0       -1

#### Previous topic

timeseries.SpaceCurve.accel

#### Next topic

timeseries.SpaceCurve.auto_bin